@@ -25,7 +25,7 @@ __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 
 __license__: str = "MIT"
-__version__: str = "0.0.3"
+__version__: str = "0.0.6"
 __email__: str = "dominic@davis-foster.co.uk"
 
 
@@ -71,6 +71,8 @@ def process_docstring(app: Sphinx, what, name, obj, options, lines: typing.List[
 					formatted_annotation = f":py:obj:`{default_value}`"
 				elif default_value is None:
 					formatted_annotation = f":py:obj:`None`"
+				elif isinstance(default_value, str):
+					formatted_annotation = f"``'{default_value.replace(' ', '␣')}'``"
 				else:
 					formatted_annotation = f"``{default_value!r}``"
 
@@ -103,11 +105,20 @@ def process_docstring(app: Sphinx, what, name, obj, options, lines: typing.List[
 
 			if formatted_annotation is not None:
 				if insert_index is not None:
-					# Ensure the previous line has a fullstop at the end.
-					if not lines[insert_index].endswith('.'):
-						lines[insert_index] += '.'
 
-					lines.insert(insert_index + 1, f'\t{default_description_format % formatted_annotation}.')
+					# Look ahead to find the index of the next unindented line, and insert before it.
+					for idx, line in enumerate(lines[insert_index + 1:]):
+						if not line.startswith("    "):
+
+							# Ensure the previous line has a fullstop at the end.
+							if lines[insert_index + idx][-1] not in ".,;:":
+								lines[insert_index + idx] += '.'
+
+							lines.insert(
+									insert_index + 1 + idx,
+									f"    {default_description_format % formatted_annotation}."
+									)
+							break
 
 		# Remove all remaining :default *: lines
 		for i, line in enumerate(lines):
